"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.testCalculations = void 0;
var _chai = require("chai");
var _describeGregorianAdapter = require("../describeGregorianAdapter");
const testCalculations = ({
  adapter
}) => {
  const testDateIso = adapter.date(_describeGregorianAdapter.TEST_DATE_ISO_STRING);
  it('Method: date', () => {
    (0, _chai.expect)(adapter.date(null)).to.equal(null);
  });
  it('Method: parse', () => {
    (0, _chai.expect)(adapter.parse('', adapter.formats.keyboardDate)).to.equal(null);
    (0, _chai.expect)(adapter.parse('01/01/1395', adapter.formats.keyboardDate)).not.to.equal(null);
  });
  it('Method: parseISO', () => {
    (0, _chai.expect)(adapter.parseISO(_describeGregorianAdapter.TEST_DATE_ISO_STRING)).toEqualDateTime(testDateIso);
  });
  it('Method: toISO', () => {
    const outputtedISO = adapter.toISO(testDateIso);
    if (adapter.lib === 'date-fns-jalali') {
      // date-fns never suppress useless milliseconds in the end
      (0, _chai.expect)(outputtedISO).to.equal(_describeGregorianAdapter.TEST_DATE_ISO_STRING.replace('.000Z', 'Z'));
    } else {
      (0, _chai.expect)(outputtedISO).to.equal(_describeGregorianAdapter.TEST_DATE_ISO_STRING);
    }
  });
  it('Method: isNull', () => {
    (0, _chai.expect)(adapter.isNull(null)).to.equal(true);
    (0, _chai.expect)(adapter.isNull(testDateIso)).to.equal(false);
  });
  describe('Method: getDiff', () => {
    it('should compute the millisecond diff when there is no unit', () => {
      (0, _chai.expect)(adapter.getDiff(testDateIso, adapter.date('2018-10-29T11:44:00.000Z'))).to.equal(86400000);
      (0, _chai.expect)(adapter.getDiff(testDateIso, adapter.date('2018-10-31T11:44:00.000Z'))).to.equal(-86400000);
      (0, _chai.expect)(adapter.getDiff(testDateIso, adapter.date('2018-10-31T11:44:00.000Z'))).to.equal(-86400000);
    });
    it('should compute the diff in the provided unit (ISO)', () => {
      (0, _chai.expect)(adapter.getDiff(testDateIso, adapter.date('2017-09-29T11:44:00.000Z'), 'years')).to.equal(1);
      (0, _chai.expect)(adapter.getDiff(testDateIso, adapter.date('2018-08-29T11:44:00.000Z'), 'months')).to.equal(2);
      (0, _chai.expect)(adapter.getDiff(testDateIso, adapter.date('2018-05-29T11:44:00.000Z'), 'quarters')).to.equal(1);
      (0, _chai.expect)(adapter.getDiff(testDateIso, adapter.date('2018-09-29T11:44:00.000Z'), 'days')).to.equal(31);
      (0, _chai.expect)(adapter.getDiff(testDateIso, adapter.date('2018-09-29T11:44:00.000Z'), 'weeks')).to.equal(4);
      (0, _chai.expect)(adapter.getDiff(testDateIso, adapter.date('2018-09-29T11:44:00.000Z'), 'hours')).to.equal(744);
      (0, _chai.expect)(adapter.getDiff(testDateIso, adapter.date('2018-09-29T11:44:00.000Z'), 'minutes')).to.equal(44640);
      (0, _chai.expect)(adapter.getDiff(testDateIso, adapter.date('2018-10-30T10:44:00.000Z'), 'seconds')).to.equal(3600);
      (0, _chai.expect)(adapter.getDiff(testDateIso, adapter.date('2018-10-30T10:44:00.000Z'), 'milliseconds')).to.equal(3600000);
    });
  });
  it('Method: isEqual', () => {
    const anotherDate = adapter.date(_describeGregorianAdapter.TEST_DATE_ISO_STRING);
    (0, _chai.expect)(adapter.isEqual(testDateIso, anotherDate)).to.equal(true);
    (0, _chai.expect)(adapter.isEqual(null, null)).to.equal(true);
  });
  it('Method: isSameYear', () => {
    (0, _chai.expect)(adapter.isSameYear(testDateIso, adapter.date('2018-10-01T00:00:00.000Z'))).to.equal(true);
    (0, _chai.expect)(adapter.isSameYear(testDateIso, adapter.date('2019-10-01T00:00:00.000Z'))).to.equal(false);
  });
  it('Method: isSameMonth', () => {
    (0, _chai.expect)(adapter.isSameMonth(testDateIso, adapter.date('2018-11-04T00:00:00.000Z'))).to.equal(true);
    (0, _chai.expect)(adapter.isSameMonth(testDateIso, adapter.date('2019-10-01T00:00:00.000Z'))).to.equal(false);
  });
  it('Method: isSameDay', () => {
    (0, _chai.expect)(adapter.isSameDay(testDateIso, adapter.date('2018-10-30T00:00:00.000Z'))).to.equal(true);
    (0, _chai.expect)(adapter.isSameDay(testDateIso, adapter.date('2019-10-30T00:00:00.000Z'))).to.equal(false);
  });
  it('Method: isSameHour', () => {
    (0, _chai.expect)(adapter.isSameHour(testDateIso, adapter.date('2018-10-30T11:00:00.000Z'))).to.equal(true);
    (0, _chai.expect)(adapter.isSameHour(testDateIso, adapter.date('2018-10-30T12:00:00.000Z'))).to.equal(false);
  });
  it('Method: isAfter', () => {
    (0, _chai.expect)(adapter.isAfter(adapter.date(), testDateIso)).to.equal(true);
    (0, _chai.expect)(adapter.isAfter(testDateIso, adapter.date())).to.equal(false);
  });
  it('Method: isAfterYear', () => {
    const afterYear = adapter.addYears(testDateIso, 2);
    (0, _chai.expect)(adapter.isAfterYear(afterYear, testDateIso)).to.equal(true);
  });
  it('Method: isAfterDay', () => {
    const nextDayIso = adapter.addDays(testDateIso, 1);
    (0, _chai.expect)(adapter.isAfterDay(nextDayIso, testDateIso)).to.equal(true);
    (0, _chai.expect)(adapter.isAfterDay(testDateIso, nextDayIso)).to.equal(false);
  });
  it('Method: isBefore', () => {
    (0, _chai.expect)(adapter.isBefore(testDateIso, adapter.date())).to.equal(true);
    (0, _chai.expect)(adapter.isBefore(adapter.date(), testDateIso)).to.equal(false);
  });
  it('Method: isBeforeYear', () => {
    const afterYear = adapter.addYears(testDateIso, 2);
    (0, _chai.expect)(adapter.isBeforeYear(testDateIso, afterYear)).to.equal(true);
  });
  it('Method: isBeforeDay', () => {
    const nextDayIso = adapter.addDays(testDateIso, -1);
    (0, _chai.expect)(adapter.isBeforeDay(nextDayIso, testDateIso)).to.equal(true);
    (0, _chai.expect)(adapter.isBeforeDay(testDateIso, nextDayIso)).to.equal(false);
  });
  it('Method: isWithinRange', () => {
    (0, _chai.expect)(adapter.isWithinRange(adapter.date('2019-10-01T00:00:00.000Z'), [adapter.date('2019-09-01T00:00:00.000Z'), adapter.date('2019-11-01T00:00:00.000Z')])).to.equal(true);
    (0, _chai.expect)(adapter.isWithinRange(adapter.date('2019-12-01T00:00:00.000Z'), [adapter.date('2019-09-01T00:00:00.000Z'), adapter.date('2019-11-01T00:00:00.000Z')])).to.equal(false);
    (0, _chai.expect)(adapter.isWithinRange(adapter.date('2019-10-01'), [adapter.date('2019-09-01'), adapter.date('2019-11-01')])).to.equal(true);
    (0, _chai.expect)(adapter.isWithinRange(adapter.date('2019-12-01'), [adapter.date('2019-09-01'), adapter.date('2019-11-01')])).to.equal(false);
  });
  it('Method: startOfYear', () => {
    (0, _chai.expect)(adapter.startOfYear(testDateIso)).toEqualDateTime('2018-03-21T00:00:00.000Z');
  });
  it('Method: startOfMonth', () => {
    (0, _chai.expect)(adapter.startOfMonth(testDateIso)).toEqualDateTime('2018-10-23T00:00:00.000Z');
  });
  it('Method: startOfWeek', () => {
    (0, _chai.expect)(adapter.startOfWeek(testDateIso)).toEqualDateTime('2018-10-27T00:00:00.000Z');
  });
  it('Method: startOfDay', () => {
    (0, _chai.expect)(adapter.startOfDay(testDateIso)).toEqualDateTime('2018-10-30T00:00:00.000Z');
  });
  it('Method: endOfYear', () => {
    (0, _chai.expect)(adapter.endOfYear(testDateIso)).toEqualDateTime('2019-03-20T23:59:59.999Z');
  });
  it('Method: endOfMonth', () => {
    (0, _chai.expect)(adapter.endOfMonth(testDateIso)).toEqualDateTime('2018-11-21T23:59:59.999Z');
  });
  it('Method: endOfWeek', () => {
    (0, _chai.expect)(adapter.endOfWeek(testDateIso)).toEqualDateTime('2018-11-02T23:59:59.999Z');
  });
  it('Method: endOfDay', () => {
    (0, _chai.expect)(adapter.endOfDay(testDateIso)).toEqualDateTime('2018-10-30T23:59:59.999Z');
  });
  it('Method: addYears', () => {
    (0, _chai.expect)(adapter.addYears(testDateIso, 2)).toEqualDateTime('2020-10-29T11:44:00.000Z');
    (0, _chai.expect)(adapter.addYears(testDateIso, -2)).toEqualDateTime('2016-10-29T11:44:00.000Z');
  });
  it('Method: addMonths', () => {
    (0, _chai.expect)(adapter.addMonths(testDateIso, 2)).toEqualDateTime('2018-12-29T11:44:00.000Z');
    (0, _chai.expect)(adapter.addMonths(testDateIso, -2)).toEqualDateTime('2018-08-30T11:44:00.000Z');
    (0, _chai.expect)(adapter.addMonths(testDateIso, 3)).toEqualDateTime('2019-01-28T11:44:00.000Z');
  });
  it('Method: addWeeks', () => {
    (0, _chai.expect)(adapter.addWeeks(testDateIso, 2)).toEqualDateTime('2018-11-13T11:44:00.000Z');
    (0, _chai.expect)(adapter.addWeeks(testDateIso, -2)).toEqualDateTime('2018-10-16T11:44:00.000Z');
  });
  it('Method: addDays', () => {
    (0, _chai.expect)(adapter.addDays(testDateIso, 2)).toEqualDateTime('2018-11-01T11:44:00.000Z');
    (0, _chai.expect)(adapter.addDays(testDateIso, -2)).toEqualDateTime('2018-10-28T11:44:00.000Z');
  });
  it('Method: addHours', () => {
    (0, _chai.expect)(adapter.addHours(testDateIso, 2)).toEqualDateTime('2018-10-30T13:44:00.000Z');
    (0, _chai.expect)(adapter.addHours(testDateIso, -2)).toEqualDateTime('2018-10-30T09:44:00.000Z');
    (0, _chai.expect)(adapter.addHours(testDateIso, 15)).toEqualDateTime('2018-10-31T02:44:00.000Z');
  });
  it('Method: addMinutes', () => {
    (0, _chai.expect)(adapter.addMinutes(testDateIso, 2)).toEqualDateTime('2018-10-30T11:46:00.000Z');
    (0, _chai.expect)(adapter.addMinutes(testDateIso, -2)).toEqualDateTime('2018-10-30T11:42:00.000Z');
    (0, _chai.expect)(adapter.addMinutes(testDateIso, 20)).toEqualDateTime('2018-10-30T12:04:00.000Z');
  });
  it('Method: addSeconds', () => {
    (0, _chai.expect)(adapter.addSeconds(testDateIso, 2)).toEqualDateTime('2018-10-30T11:44:02.000Z');
    (0, _chai.expect)(adapter.addSeconds(testDateIso, -2)).toEqualDateTime('2018-10-30T11:43:58.000Z');
    (0, _chai.expect)(adapter.addSeconds(testDateIso, 70)).toEqualDateTime('2018-10-30T11:45:10.000Z');
  });
  it('Method: getYear', () => {
    (0, _chai.expect)(adapter.getYear(testDateIso)).to.equal(1397);
  });
  it('Method: getMonth', () => {
    (0, _chai.expect)(adapter.getMonth(testDateIso)).to.equal(7);
  });
  it('Method: getDate', () => {
    (0, _chai.expect)(adapter.getDate(testDateIso)).to.equal(8);
  });
  it('Method: setYear', () => {
    (0, _chai.expect)(adapter.setYear(testDateIso, 1398)).toEqualDateTime('2019-10-30T11:44:00.000Z');
  });
  it('Method: setMonth', () => {
    (0, _chai.expect)(adapter.setMonth(testDateIso, 4)).toEqualDateTime('2018-07-30T11:44:00.000Z');
  });
  it('Method: setDate', () => {
    (0, _chai.expect)(adapter.setDate(testDateIso, 9)).toEqualDateTime('2018-10-31T11:44:00.000Z');
  });
  it('Method: getNextMonth', () => {
    (0, _chai.expect)(adapter.getNextMonth(testDateIso)).toEqualDateTime('2018-11-29T11:44:00.000Z');
  });
  it('Method: getPreviousMonth', () => {
    (0, _chai.expect)(adapter.getPreviousMonth(testDateIso)).toEqualDateTime(new Date('2018-09-30T11:44:00.000Z'));
  });
  it('Method: getMonthArray', () => {
    const monthArray = adapter.getMonthArray(testDateIso);
    let expectedDate = adapter.date('2018-03-21T00:00:00.000Z');
    monthArray.forEach(month => {
      (0, _chai.expect)(month).toEqualDateTime(expectedDate);
      expectedDate = adapter.addMonths(expectedDate, 1);
    });
  });
  it('Method: mergeDateAndTime', () => {
    const mergedDate = adapter.mergeDateAndTime(testDateIso, adapter.date('2018-01-01T14:15:16.000Z'));
    (0, _chai.expect)(adapter.toJsDate(mergedDate)).toEqualDateTime('2018-10-30T14:15:16.000Z');
  });
  it('Method: getWeekdays', () => {
    // TODO: AdapterDateFnsJalali `getWeekDays` method seems broken
    // Same behavior with the date-io adapter.
    (0, _chai.expect)(adapter.getWeekdays()).to.deep.equal(adapter.lib === 'date-fns-jalali' ? ['ش', '1ش', '2ش', '3ش', '4ش', '5ش', 'ج'] : ['ش', 'ی', 'د', 'س', 'چ', 'پ', 'ج']);
  });
  it('Method: getWeekArray', () => {
    const weekArray = adapter.getWeekArray(testDateIso);
    const expectedDate = new Date('2018-10-20T00:00:00.000Z');
    weekArray.forEach(week => {
      week.forEach(day => {
        (0, _chai.expect)(day).toEqualDateTime(expectedDate);
        expectedDate.setDate(expectedDate.getDate() + 1);
      });
    });
  });
  it('Method: getWeekNumber', () => {
    (0, _chai.expect)(adapter.getWeekNumber(testDateIso)).to.equal(33);
  });
  it('Method: getYearRange', () => {
    const anotherDate = adapter.setYear(testDateIso, 1400);
    const yearRange = adapter.getYearRange(testDateIso, anotherDate);
    (0, _chai.expect)(yearRange).to.have.length(4);
  });
};
exports.testCalculations = testCalculations;